@@ -1,5 +1,3 @@
-from greble_flow.managment.manager import FlowManager
-
 import click
 
 
@@ -10,5 +8,5 @@ def cli():
 
 @cli.command()
 def runprocessor():
-    from web.managment import app
+    from greble_flow.web.managment import app
     app.run()
