@@ -1,6 +1,6 @@
 from flask import Flask, jsonify, request, abort
 
-from managment.manager import FlowManager
+from greble_flow.managment.manager import FlowManager
 
 app = Flask(__name__)
 flow_manager = FlowManager()
